about summary refs log tree commit diff
path: root/config.h
diff options
context:
space:
mode:
authorManuel Palenzuela <manuelpalenzuelamerino@gmail.com>2019-06-19 01:28:32 +0200
committerManuel Palenzuela <manuelpalenzuelamerino@gmail.com>2019-06-19 01:28:32 +0200
commit4c844d7a9d90e05ba6cef17dd318f62466ed1687 (patch)
tree84aed9a11a604761778ba0a0c7c2837b1afabcf8 /config.h
parentModified togglefullscreen patch (diff)
downloaddwm-4c844d7a9d90e05ba6cef17dd318f62466ed1687.tar.gz
dwm-4c844d7a9d90e05ba6cef17dd318f62466ed1687.tar.bz2
dwm-4c844d7a9d90e05ba6cef17dd318f62466ed1687.zip
Added the option for rounded corners [Patch]
Diffstat (limited to 'config.h')
-rw-r--r--config.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/config.h b/config.h
index 95b9ea1..a9866e4 100644
--- a/config.h
+++ b/config.h
@@ -1,12 +1,14 @@
 /* See LICENSE file for copyright and license details. */
 
 /* appearance */
-static const unsigned int borderpx  = 1;        /* border pixel of windows */
+static const unsigned int borderpx  = 1;         /* border pixel of windows */
 static const unsigned int gappx     = 10;        /* gap pixel between windows */
-static const unsigned int snap      = 32;       /* snap pixel */
-static const int showbar            = 1;        /* 0 means no bar */
-static const int topbar             = 1;        /* 0 means bottom bar */
-static const int focusonwheel       = 0;				/* 0 means no focus when click mouse wheel */
+static const unsigned int corner_radius = 0;     /* rounded corners radius */
+static const unsigned int round_non_floating = 1;/* if 0 only floating windows rounded */
+static const unsigned int snap      = 32;        /* snap pixel */
+static const int showbar            = 1;         /* 0 means no bar */
+static const int topbar             = 1;         /* 0 means bottom bar */
+static const int focusonwheel       = 0;				 /* 0 means no focus when click mouse wheel */
 static const char *fonts[]          = { "Noto Sans Display Nerd Font:size=10" };
 static const char dmenufont[]       = "Noto Sans Display Nerd Font:size=10";
 static const char col_gray1[]       = "#222222";